Welcome to Ladybug's documentation!
===================================

.. image:: http://www.ladybug.tools/assets/img/ladybug.png

Ladybug is a Python library to load, analyze and modify EnergyPlus Weather files (epw).
You can download epw files from `EPWMap <http://www.ladybug.tools/epwmap/>`_.

Installation
============

``pip install -U ladybug-core``


.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. include:: modules.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
